@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.7'
+    version = '1.0.8'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
@@ -57,7 +57,7 @@ class DingDingPlugin(NotificationPlugin):
         data = {
             "msgtype": "markdown",
             "markdown": {
-                "event": str(event)
+                "event": str(event),
                 "title": title,
                 "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
